# NotificationModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**created_date** | **datetime, none_type** |  | [optional] 
**is_read** | **bool** |  | [optional] 
**entity_id** | **str** |  | [optional] 
**notification_type** | [**NotificationTypeModel**](NotificationTypeModel.md) |  | [optional] 
**project_global_id** | **int, none_type** |  | [optional] 
**project_name** | **str, none_type** |  | [optional] 
**test_plan_global_id** | **int** |  | [optional] 
**test_plan_name** | **str, none_type** |  | [optional] 
**workitem_global_id** | **int, none_type** |  | [optional] 
**comment** | **str, none_type** |  | [optional] 
**work_item_name** | **str, none_type** |  | [optional] 
**attribute_name** | **str, none_type** |  | [optional] 
**created_by_id** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


